<!--- To get started, just set the user-defined constants in the first portion of OnApplicationStart.
			Additionally, there are some debugging settings you can set in OnRequest --->

<cfcomponent>


<!--- standard application settings --->
<cfset this.Name = "myAppName_v1_000">
<cfset this.ApplicationTimeout = CreateTimeSpan(30,0,0,0)>
<cfset this.SessionTimeout = CreateTimespan(30,0,0,0)>
<cfset this.SessionManagement = true>
<cfset this.SetClientCookies = true>

<cfsetting requesttimeout="20" showdebugoutput="true" enablecfoutputonly="false" />

<cffunction name="OnApplicationStart" access="public" returntype="boolean" output="false" hint="Fires when the application is first created.">
	
	<!--- padsite's user-defined constants (EDIT THESE VALUES FOR YOUR APP) --->
	<cfset Application.psSiteTitle = "My Site Title"><!--- padsite displays psSiteTitle in most html title tags --->
	<cfset Application.psDataSource = "myDSN">
	<!--- padsite will prefix all the tables it creates with Application.psTablePrefix --->
	<cfset Application.psTablePrefix = "myTablePrefix_">
	<cfset Application.psMailServer = "localhost">
	<!--- access details --->
	<cfset Application.psDefaultAccessLevels = "Webmaster,Administrator">
	<cfset Application.psConfigAccess = "Webmaster"><!--- allowed to access /padsite/setup.cfm and sql editor (formerly /admin/config/...) --->
	<!--- webmaster details - for error notifications --->
	<cfset Application.psWebmaster.Email = "you@domain.com">
	<cfset Application.psWebmaster.FirstName = "Padsite">
	<cfset Application.psWebmaster.LastName = "User">
	<!--- security settings --->
	<cfset Application.psEncAlgorithm = "AES">
	<cfset Application.psEncKey = ""><!--- <cfoutput>#GenerateSecretKey(Application.psEncAlgorithm,128)#</cfoutput> --->
	<cfset Application.psIllegal_URL_Chars = ";/*%##'\">
	<!--- misc settings --->
	<cfset Application.psPageGen.MakeBackups = false>
	
	<!--- padsite's internal constants (NO NEED TO EDIT, GENERALLY) --->
	<!--- standard system tables --->
	<cfset Application.psAccountsTable = Application.psTablePrefix&"People">
	<cfset Application.psGroupsTable = Application.psTablePrefix&"Groups">
	<cfset Application.psLoginsTable = Application.psTablePrefix&"Logins">
	<cfset Application.psSchemaTable = Application.psTablePrefix&"Schema">
	<cfset Application.psSearchTable = Application.psTablePrefix&"Searches">
	<cfset Application.psAdminPagesTable = Application.psTablePrefix&"AdminPages">
	<cfset Application.psMessageLogTable = Application.psTablePrefix&"MessageLog">
	<cfset Application.psSystemTables = "'#Application.psAccountsTable#','#Application.psSchemaTable#','#Application.psSearchTable#','#Application.psAdminPagesTable#','#Application.psLoginsTable#','#Application.psMessageLogTable#'">
	<!--- supported data types --->
	<cfset Application.psNumericDataTypes = "bit,int,money">
	<cfset Application.psStandardDataTypes = "bit,datetime,int,money,text,varchar">
	<cfset Application.psNonStandardDataTypes = "filter,iframe,list,custom">
	<cfset Application.psListOfPrimaryDataTypes = "#Application.psStandardDataTypes#,#Application.psNonStandardDataTypes#">
	<!--- controller types (agents) --->
	<cfset Application.psListOfMultipleEntityPageSubtypes = "reporter,calendar">
	<cfset Application.psListOfSingleEntityPageSubtypes = "editor,viewer,gallery">
	<cfset Application.psListOfPageSubtypes = "#Application.psListOfMultipleEntityPageSubtypes#,#Application.psListOfSingleEntityPageSubtypes#">
	<!--- special characters --->
	<cfset Application.psCrLf = Chr(13) & Chr(10)>
	<cfset Application.psIllegal_URL_Chars = ";/*%##'\">
	<!--- initial setup --->
	<cfinclude template="/padsite/services/_lib/createTables.cfm">
	<cfset SetupMode = true>
	<cfinclude template="/padsite/services/_lib/page_gen_all.cfm">
	<!--- update old schema versions --->
	<cfif false>
		<cfquery name="RenameColumns" dataSource="#Application.psDataSource#">
		EXEC sp_rename '#Application.psTablePrefix#.DataTable', 'TableName', 'COLUMN';
		EXEC sp_rename '#Application.psTablePrefix#.DataField', 'FieldName', 'COLUMN';
		</cfquery>
	</cfif>
	<cfreturn true />
</cffunction>


<cffunction name="OnSessionStart" access="public" returntype="void" output="false" hint="Fires when the session is first created.">
	<cfreturn />
</cffunction>


<cffunction name="OnRequestStart" access="public" returntype="boolean" output="false" hint="Fires at first part of page processing.">
	<cfargument name="TargetPage" type="string" required="true" />
	<cfreturn true />
</cffunction>


<cffunction name="OnRequest" access="public" returntype="void" output="true" hint="Fires after pre page processing is complete.">
	<cfargument name="TargetPage" type="string" required="true" />
	<cfparam name="Session.Name" default="Anonymous">
	<cfparam name="Session.Email" default="">
	<cfparam name="Session.Access" default="">
	<cfif IsDefined("Session.Access") and Session.Access eq "Webmaster">
		<cfset Request.psDebugMode = true>
		<cfset Request.psVerboseDebugging = true>
		<cfelse>
		<cfset Request.psDebugMode = true>
		<cfset Request.psVerboseDebugging = true>
	</cfif>
	<cfif (FindNoCase("_lib",TargetPage) or FindNoCase("_template",TargetPage) or FindNoCase("views",TargetPage)) and Session.Access eq "">
		<cflocation url="/padsite/index.cfm">
		<cfabort>
	</cfif>
	<cfinclude template="#ARGUMENTS.TargetPage#" />
	<cfreturn />
</cffunction>


<cffunction name="OnRequestEnd" access="public" returntype="void" output="true" hint="Fires after the page processing is complete.">
	<cfreturn />
</cffunction>


<cffunction name="OnSessionEnd" access="public" returntype="void" output="false" hint="Fires when the session is terminated.">
	<cfargument name="SessionScope" type="struct" required="true" />
	<cfargument name="ApplicationScope" type="struct" required="false" default="#StructNew()#" />
	<cfreturn />
</cffunction>


<cffunction name="OnApplicationEnd" access="public" returntype="void" output="false" hint="Fires when the application is terminated.">
	<cfargument name="ApplicationScope" type="struct" required="false" default="#StructNew()#" />
	<cfreturn />
</cffunction>


<cffunction name="OnError" access="public" returntype="void" output="true" hint="Fires when an exception occures that is not caught by a try/catch.">
	<cfargument name="Exception" type="any" required="true" />
	<cfargument name="EventName" type="string" required="false" default="" />
	<cfparam name="Request.psDebugMode" default="false">
	<cfparam name="Request.psVerboseDebugging" default="false">
	<cfif Request.psDebugMode>
		<cfinclude template="/padsite/views/adminErrorNotification.cfm">
		<cfif Request.psVerboseDebugging>
			<cfdump var="#EventName#">
			<cfdump var="#Exception#">
			<cfdump var="#form#" label="Form">
			<cfdump var="#url#" label="URL">
			<cfdump var="#cgi#" label="CGI">
		</cfif>
		<cfelse>
		<p>An error has occurred. The webmaster has been alerted to the problem.</p>
		<p>If the problem persists, you may email the webmaster at <a href="mailto:#Application.psWebmaster.Email#">#Application.psWebmaster.Email#</a></p>
		<cfmail to="#Application.psWebmaster.Email#" from="#Application.psWebmaster.Email#" subject="#Application.ApplicationName# Error: #Exception.Cause.Message#" type="html" server="#Application.psMailServer#">
			<cfinclude template="/padsite/views/adminErrorNotification.cfm">
		</cfmail>
	</cfif>
	<cfreturn />
</cffunction>


</cfcomponent>
