It is assumed that the calendar's table has the following fields..
	#RecordName# (varchar) (record name as defined in controller (/padsite/user/...) for use in view (/padsite/views/...))
	Start (datetime)
	Stop (datetime)
	AllDayEvent (bit)
	RecurringEvent (bit)
	RecurringInterval (varchar) currently supporting daily, weekly, monthly and yearly as valid values
	RecurringThrough (datetime)
	

<cfcomponent>


<cffunction name="psReadCalendar" access="public" returnType="struct" hint="queries tablename for events based on view, select and current view offset">
	<cfargument name="TableName" type="string" required="true">
	<cfargument name="View" type="string" required="false" default="m">
	<cfargument name="Offset" type="numeric" required="false" default="0">
	<cfargument name="Select" type="string" required="false" default="">
	<cfset local.Results.Query = "">
	<cfset local.Results.TotalRecords = 0>
	<cfset local.Results.HasVisibleQueueField = false>
	<cfset local.Results.FilterMenu = "">
	<cfset local.Results.Success = false>
	<cfset local.Results.ErrorMessage = "">
	<!--- <cftry> --->
	
	
	<!--- <cfparam name="url.month" default="0">
	<cfparam name="url.select" default=""> --->
	<cfset local.CurrentYear = Year(DateAdd(View,Offset,now()))>
	<cfset local.CurrentMonth = Month(DateAdd(View,Offset,now()))>
	<cfquery name="local.Schema" datasource="#Application.psDataSource#">
	select * from #Application.psSchemaTable# where TableName = '#arguments.TableName#' order by Queue
	</cfquery>
	
	
	<!--- first, build an ID list of all the records that meet the search criteria --->
	<cfif Find("search",Select) and ListLen(Select,".") gte 2>
	  <!--- perform search query --->
	  <cfquery name="local.Search" datasource="#Application.psDataSource#">
	  select * from #Application.psSearchTable# where ID = #Val(ListGetAt(Select,2,"."))#
	  </cfquery>
	  <cfquery name="local.Table" datasource="#Application.psDataSource#">
	  #Replace(PreserveSingleQuotes(local.Search.QueryString),"*","ID")#
	  </cfquery>
	  <cfset local.SearchIDList = ValueList(local.Table.ID)>
		<cfelse>
		<cfset local.SearchIDList = "">
	</cfif>
	
	
	<!--- next, get all the non-recurring events in the given year or month (or week) --->
	<cfquery name="local.GetEventsTemp" datasource="#Application.psDataSource#">
	select * FROM #arguments.TableName# where
	<cfswitch expression="#View#">
		<cfcase value="ww,m">
		datepart(year,Start) = '#local.CurrentYear#' and datepart(month,Start) = '#local.CurrentMonth#' and (RecurringEvent is null or RecurringEvent = 0)
		</cfcase>
		<cfcase value="yyyy">
		datepart(year,Start) = '#local.CurrentYear#' and (RecurringEvent is null or RecurringEvent = 0)
		</cfcase>
	</cfswitch>
	<cfif IsDefined("url.parent") and IsNumeric(url.parent) and IsDefined("ParentTable")>
	  and #ParentTable#ID = #Val(url.parent)#
	</cfif>
	order by Start, Stop
	</cfquery>
	
	
	<!--- next, get all the recurring events and see if they occur during the current 'view' --->
	<cfquery name="local.GetRecurringEvents" datasource="#Application.psDataSource#">
	select * from #arguments.TableName# where RecurringEvent = 1 order by Start, Stop
	</cfquery>
	<cfif View eq "yyyy">
		<cfset local.Multiplier = 13>
		<cfelse>
		<cfset local.Multiplier = 1>
	</cfif>
	<cfif local.GetRecurringEvents.RecordCount>
	  <cfloop from="1" to="#local.GetRecurringEvents.RecordCount#" index="local.i">
	  	<cfif local.GetRecurringEvents.Stop[local.i] eq "">
	  		<cfset local.GetRecurringEvents.Stop[local.i] = local.GetRecurringEvents.Start[local.i]>
	  	</cfif>
	  	<cfswitch expression="#local.GetRecurringEvents.RecurringInterval[local.i]#">
	  		<cfcase value="Daily">
	  		<cfset local.DateCode = "d">
	  		<cfset local.LoopTo = 31 * local.Multiplier>
	  		</cfcase>
	  		<cfcase value="Weekly">
	  		<cfset local.DateCode = "ww">
	  		<cfset local.LoopTo = 5 * local.Multiplier>
	  		</cfcase>
	  		<cfcase value="Monthly">
	  		<cfset local.DateCode = "m">
	  		<cfset local.LoopTo = 1 * local.Multiplier>
	  		</cfcase>
	  		<cfcase value="Yearly">
	  		<cfset local.DateCode = "yyyy">
	  		<cfset local.LoopTo = 1>
	  		</cfcase>
	  		<cfdefaultcase>
	  		<cfabort showError="Unsupported recurring interval">
	  		</cfdefaultcase>
	  	</cfswitch>
	  	<cfif View eq "yyyy">
	  		<cfset local.CurrentStartDateDifference = DateDiff(local.DateCode,local.GetRecurringEvents.Start[local.i],CreateDate(local.CurrentYear,1,1))>
	  		<cfelse>
	  		<cfset local.CurrentStartDateDifference = DateDiff(local.DateCode,local.GetRecurringEvents.Start[local.i],CreateDate(local.CurrentYear,local.CurrentMonth,1))>
	  	</cfif>
	  	<cfset local.CurrentAdjustedStartDate = DateAdd(local.DateCode,local.CurrentStartDateDifference,local.GetRecurringEvents.Start[local.i])>
	  	<cfloop from="0" to="#local.LoopTo#" index="local.j">
	  		<cfset local.ProposedDate = DateAdd(local.DateCode,local.j,local.CurrentAdjustedStartDate)>
	  		<cfif local.ProposedDate gte local.GetRecurringEvents.Start[local.i]>
	  			<cfif Year(local.ProposedDate) eq local.CurrentYear>
	  				<cfif arguments.View eq "yyyy" or (arguments.View eq "m" and Month(local.ProposedDate) eq local.CurrentMonth)>
	  					<cfif local.ProposedDate lte local.GetRecurringEvents.RecurringThrough[local.i]>
	  						
	  						<!--- proposed date fits all the criterial for a valid recurring event so add to query --->
				  			<cfset local.EventDuration = DateDiff("n",local.GetRecurringEvents.Start[local.i],local.GetRecurringEvents.Stop[local.i])>
				  			<cfset QueryAddRow(local.GetEventsTemp)>
				  			<cfset QuerySetCell(local.GetEventsTemp,"ID",local.GetRecurringEvents.ID[local.i])>
				  			<cfset QuerySetCell(local.GetEventsTemp,"Start",local.ProposedDate)>
				  			<cfset QuerySetCell(local.GetEventsTemp,"Stop",DateAdd("n",local.EventDuration,local.ProposedDate))>
				  			<cfset local.k = 0>
				  			<cfloop list="#ValueList(local.Schema.FieldName)#" index="local.CurrentItem">
				  				<cfset local.k = local.k + 1>
				  				<cfif not ListFind("Start,Stop",local.CurrentItem) and (local.Schema.Display[local.k] or local.Schema.Editable[local.k])>
				  					<cfset QuerySetCell(local.GetEventsTemp,"#local.CurrentItem#",Evaluate("local.GetRecurringEvents.#local.CurrentItem#[local.i]"))>
				  				</cfif>
				  			</cfloop>
	  						
	  					</cfif>
	  				</cfif>
	  			</cfif>
	  		</cfif>
	  	</cfloop>
	  </cfloop>
	</cfif>
	<!--- <cfdump var="#local.GetEventsTemp#" label="GetEventsTemp"> --->
	<!--- end recurring event processing --->
	<cfquery name="local.GetEvents" dbtype="query">
	select * from [local].GetEventsTemp
	<cfif local.SearchIDList neq "">
		where ID in (#local.SearchIDList#)
	</cfif>
	order by Start, Stop
	</cfquery>
	<cfquery name="local.GetEventsTotal" dbtype="query">
	select * from [local].GetEventsTemp order by Start, Stop
	</cfquery>
		
		<!--- <cfcatch type="any">
			<cfset results.errorMessage = "An error occurred while retrieving the table.">
			<cfthrow message="wtf?">
		</cfcatch>
	</cftry> --->
	<cfset local.Results.Success = true>
	<cfset local.Results.Query = local.GetEvents>
	<cfset local.Results.TotalRecords = local.GetEventsTotal.RecordCount>
	<!--- <cfset Results.HasVisibleQueueField = false> --->
	<cfset local.Results.FilterMenu = "">
	
	<!--- <cfset Results.DisplaySendMail = false> --->
	<cfparam name="local.DisplayParentSendmail" default="false">
	<cfset local.Results.DisplayParentSendmail = local.DisplayParentSendmail>
	<cfset local.Results.Schema = local.Schema>
	
	<cfset local.Results.CurrentMonth = local.CurrentMonth>
	<cfset local.Results.CurrentYear = local.CurrentYear>
	
	<cfreturn Results>
</cffunction>


</cfcomponent>
